# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`opensearch`](#opensearch): Module to manage opensearch.

#### Private Classes

* `opensearch::config`: Configure opensearch.
* `opensearch::install`: Installs opensearch via archive, package, or repository.
* `opensearch::install::archive`: Install opensearch via tarball.
* `opensearch::install::package`: Install opensearch via deb/rpm package.
* `opensearch::repository`: Handle opensearch repository.
* `opensearch::repository::debian`: Install the Debian apt repository for opensearch.
* `opensearch::repository::redhat`: Install the RedHat yum repository for opensearch.
* `opensearch::service`: Handle opensearch service.

## Classes

### <a name="opensearch"></a>`opensearch`

Module to manage opensearch.

#### Parameters

The following parameters are available in the `opensearch` class:

* [`version`](#-opensearch--version)
* [`manage_package`](#-opensearch--manage_package)
* [`package_source`](#-opensearch--package_source)
* [`package_ensure`](#-opensearch--package_ensure)
* [`package_architecture`](#-opensearch--package_architecture)
* [`package_provider`](#-opensearch--package_provider)
* [`package_directory`](#-opensearch--package_directory)
* [`pin_package`](#-opensearch--pin_package)
* [`apt_pin_priority`](#-opensearch--apt_pin_priority)
* [`manage_config`](#-opensearch--manage_config)
* [`use_default_settings`](#-opensearch--use_default_settings)
* [`default_settings`](#-opensearch--default_settings)
* [`settings`](#-opensearch--settings)
* [`use_default_notifications_notifications`](#-opensearch--use_default_notifications_notifications)
* [`notifications_notifications`](#-opensearch--notifications_notifications)
* [`use_default_notifications_notifications_core`](#-opensearch--use_default_notifications_notifications_core)
* [`notifications_notifications_core`](#-opensearch--notifications_notifications_core)
* [`use_default_observability_observability`](#-opensearch--use_default_observability_observability)
* [`observability_observability`](#-opensearch--observability_observability)
* [`use_default_reporting_reports_scheduler`](#-opensearch--use_default_reporting_reports_scheduler)
* [`reporting_reports_scheduler`](#-opensearch--reporting_reports_scheduler)
* [`use_default_security_action_groups`](#-opensearch--use_default_security_action_groups)
* [`security_action_groups`](#-opensearch--security_action_groups)
* [`use_default_security_allowlist`](#-opensearch--use_default_security_allowlist)
* [`security_allowlist`](#-opensearch--security_allowlist)
* [`use_default_security_audit`](#-opensearch--use_default_security_audit)
* [`security_audit`](#-opensearch--security_audit)
* [`use_default_security_config`](#-opensearch--use_default_security_config)
* [`security_config`](#-opensearch--security_config)
* [`use_default_security_internal_users`](#-opensearch--use_default_security_internal_users)
* [`security_internal_users`](#-opensearch--security_internal_users)
* [`use_default_security_nodes_dn`](#-opensearch--use_default_security_nodes_dn)
* [`security_nodes_dn`](#-opensearch--security_nodes_dn)
* [`use_default_security_roles_mapping`](#-opensearch--use_default_security_roles_mapping)
* [`security_roles_mapping`](#-opensearch--security_roles_mapping)
* [`use_default_security_roles`](#-opensearch--use_default_security_roles)
* [`security_roles`](#-opensearch--security_roles)
* [`use_default_security_tenants`](#-opensearch--use_default_security_tenants)
* [`security_tenants`](#-opensearch--security_tenants)
* [`use_default_security_whitelist`](#-opensearch--use_default_security_whitelist)
* [`security_whitelist`](#-opensearch--security_whitelist)
* [`heap_size`](#-opensearch--heap_size)
* [`manage_service`](#-opensearch--manage_service)
* [`service_ensure`](#-opensearch--service_ensure)
* [`service_enable`](#-opensearch--service_enable)
* [`restart_on_config_change`](#-opensearch--restart_on_config_change)
* [`restart_on_package_change`](#-opensearch--restart_on_package_change)
* [`manage_repository`](#-opensearch--manage_repository)
* [`repository_ensure`](#-opensearch--repository_ensure)
* [`repository_location`](#-opensearch--repository_location)
* [`repository_gpg_key`](#-opensearch--repository_gpg_key)

##### <a name="-opensearch--version"></a>`version`

Data type: `Optional[String]`

The version to be installed. See also: https://opensearch.org/downloads.html

Default value: `undef`

##### <a name="-opensearch--manage_package"></a>`manage_package`

Data type: `Boolean`

Whether to manage the package installation-

Default value: `true`

##### <a name="-opensearch--package_source"></a>`package_source`

Data type: `Enum['archive', 'download', 'repository']`

The source for the package.

Default value: `'repository'`

##### <a name="-opensearch--package_ensure"></a>`package_ensure`

Data type: `Enum['present', 'absent']`

The status of the package.

Default value: `'present'`

##### <a name="-opensearch--package_architecture"></a>`package_architecture`

Data type: `Enum['x64', 'arm64']`

The architecture for the package.

##### <a name="-opensearch--package_provider"></a>`package_provider`

Data type: `Enum['dpkg', 'rpm']`

The provider for the package to be used to install the package.

##### <a name="-opensearch--package_directory"></a>`package_directory`

Data type: `Stdlib::Absolutepath`

The directory to install the package. Only used for package_install_method = 'archive'.

Default value: `'/opt/opensearch'`

##### <a name="-opensearch--pin_package"></a>`pin_package`

Data type: `Boolean`

Whether to enable the `apt::pin` or `yum::versionlock` for the package

Default value: `true`

##### <a name="-opensearch--apt_pin_priority"></a>`apt_pin_priority`

Data type: `Integer`

The priority for apt::pin of the opensearch package

Default value: `1001`

##### <a name="-opensearch--manage_config"></a>`manage_config`

Data type: `Boolean`

Whether to manage the configuration.

Default value: `true`

##### <a name="-opensearch--use_default_settings"></a>`use_default_settings`

Data type: `Boolean`

Whether to use the modules default settings values.

Default value: `true`

##### <a name="-opensearch--default_settings"></a>`default_settings`

Data type: `Hash`

The modules default settings for opensearch.

##### <a name="-opensearch--settings"></a>`settings`

Data type: `Hash`

Additional settings for opensearch.

Default value: `{}`

##### <a name="-opensearch--use_default_notifications_notifications"></a>`use_default_notifications_notifications`

Data type: `Boolean`

Whether to use the module default notification settings

Default value: `true`

##### <a name="-opensearch--notifications_notifications"></a>`notifications_notifications`

Data type: `Hash`

Additional notification settings

Default value: `{}`

##### <a name="-opensearch--use_default_notifications_notifications_core"></a>`use_default_notifications_notifications_core`

Data type: `Boolean`

Whether to use the module default notification-core settings

Default value: `true`

##### <a name="-opensearch--notifications_notifications_core"></a>`notifications_notifications_core`

Data type: `Hash`

Additional notification-core settings

Default value: `{}`

##### <a name="-opensearch--use_default_observability_observability"></a>`use_default_observability_observability`

Data type: `Boolean`

Whether to use the module default observability settings

Default value: `true`

##### <a name="-opensearch--observability_observability"></a>`observability_observability`

Data type: `Hash`

Additional observability settings

Default value: `{}`

##### <a name="-opensearch--use_default_reporting_reports_scheduler"></a>`use_default_reporting_reports_scheduler`

Data type: `Boolean`

Whether to use the module default reports-scheduler settings

Default value: `true`

##### <a name="-opensearch--reporting_reports_scheduler"></a>`reporting_reports_scheduler`

Data type: `Hash`

Additional reports-scheduler settings

Default value: `{}`

##### <a name="-opensearch--use_default_security_action_groups"></a>`use_default_security_action_groups`

Data type: `Boolean`

Whether to use the module default security action_groups settings

Default value: `true`

##### <a name="-opensearch--security_action_groups"></a>`security_action_groups`

Data type: `Hash`

Additional security action_groups settings

Default value: `{}`

##### <a name="-opensearch--use_default_security_allowlist"></a>`use_default_security_allowlist`

Data type: `Boolean`

Whether to use the module default security allowlist settings

Default value: `true`

##### <a name="-opensearch--security_allowlist"></a>`security_allowlist`

Data type: `Hash`

Additional security allowlist settings

Default value: `{}`

##### <a name="-opensearch--use_default_security_audit"></a>`use_default_security_audit`

Data type: `Boolean`

Whether to use the module default security audit settings

Default value: `true`

##### <a name="-opensearch--security_audit"></a>`security_audit`

Data type: `Hash`

Additional security audit settings

Default value: `{}`

##### <a name="-opensearch--use_default_security_config"></a>`use_default_security_config`

Data type: `Boolean`

Whether to use the module default security config settings

Default value: `true`

##### <a name="-opensearch--security_config"></a>`security_config`

Data type: `Hash`

Additional security config settings

Default value: `{}`

##### <a name="-opensearch--use_default_security_internal_users"></a>`use_default_security_internal_users`

Data type: `Boolean`

Whether to use the module default security internal_users settings

Default value: `true`

##### <a name="-opensearch--security_internal_users"></a>`security_internal_users`

Data type: `Hash`

Additional security internal_users settings

Default value: `{}`

##### <a name="-opensearch--use_default_security_nodes_dn"></a>`use_default_security_nodes_dn`

Data type: `Boolean`

Whether to use the module default security nodes_dn settings

Default value: `true`

##### <a name="-opensearch--security_nodes_dn"></a>`security_nodes_dn`

Data type: `Hash`

Additional security nodes_dn settings

Default value: `{}`

##### <a name="-opensearch--use_default_security_roles_mapping"></a>`use_default_security_roles_mapping`

Data type: `Boolean`

Whether to use the module default security roles_mapping settings

Default value: `true`

##### <a name="-opensearch--security_roles_mapping"></a>`security_roles_mapping`

Data type: `Hash`

Additional security roles_mapping settings

Default value: `{}`

##### <a name="-opensearch--use_default_security_roles"></a>`use_default_security_roles`

Data type: `Boolean`

Whether to use the module default security roles settings

Default value: `true`

##### <a name="-opensearch--security_roles"></a>`security_roles`

Data type: `Hash`

Additional security roles settings

Default value: `{}`

##### <a name="-opensearch--use_default_security_tenants"></a>`use_default_security_tenants`

Data type: `Boolean`

Whether to use the module default security tenants settings

Default value: `true`

##### <a name="-opensearch--security_tenants"></a>`security_tenants`

Data type: `Hash`

Additional security tenants settings

Default value: `{}`

##### <a name="-opensearch--use_default_security_whitelist"></a>`use_default_security_whitelist`

Data type: `Boolean`

Whether to use the module default security whitelist settings

Default value: `true`

##### <a name="-opensearch--security_whitelist"></a>`security_whitelist`

Data type: `Hash`

Additional security whitelist settings

Default value: `{}`

##### <a name="-opensearch--heap_size"></a>`heap_size`

Data type: `Pattern[/\d+[mg]/]`

The heap size for the JVM.

Default value: `'512m'`

##### <a name="-opensearch--manage_service"></a>`manage_service`

Data type: `Boolean`

Whether to manage the opensearch service.

Default value: `true`

##### <a name="-opensearch--service_ensure"></a>`service_ensure`

Data type: `Stdlib::Ensure::Service`

The state for the opensearch service.

Default value: `'running'`

##### <a name="-opensearch--service_enable"></a>`service_enable`

Data type: `Boolean`

Whether to enable the service.

Default value: `true`

##### <a name="-opensearch--restart_on_config_change"></a>`restart_on_config_change`

Data type: `Boolean`

Restart the service on any config changes

Default value: `true`

##### <a name="-opensearch--restart_on_package_change"></a>`restart_on_package_change`

Data type: `Boolean`

Restart the service on package changes

Default value: `true`

##### <a name="-opensearch--manage_repository"></a>`manage_repository`

Data type: `Boolean`



Default value: `true`

##### <a name="-opensearch--repository_ensure"></a>`repository_ensure`

Data type: `Enum['present', 'absent']`



Default value: `'present'`

##### <a name="-opensearch--repository_location"></a>`repository_location`

Data type: `Optional[Stdlib::HTTPUrl]`



Default value: `undef`

##### <a name="-opensearch--repository_gpg_key"></a>`repository_gpg_key`

Data type: `Stdlib::HTTPUrl`



Default value: `'https://artifacts.opensearch.org/publickeys/opensearch.pgp'`

